==> sx-dbutils-0.1-sources.jar: jp/sourceforge/sxdbutils/query/SimpleUpdateBuilder.java <==
package jp.sourceforge.sxdbutils.query;

import java.math.BigDecimal;
import java.util.Date;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
/**
 * UPDATE文の {@link Query}を作成するためのビルダーです。
 * @author chinpei
 *
 */
public class SimpleUpdateBuilder {
	private final String tableName;
	private Map updateColumnMap = new LinkedHashMap();
	private Map whereColumnMap = new LinkedHashMap();

	private String versionColumnName;
	private Object versionColumnValue;
	private static final BigDecimal BIGDECIMAL_ONE=new BigDecimal("1");


	public SimpleUpdateBuilder addUpdateColumn(String columnName,
			Object value) {
		updateColumnMap.put(columnName, value);
		return this;
	}
	public SimpleUpdateBuilder addUpdateColumn(Map columnMap) {
		updateColumnMap.putAll(columnMap);
		return this;
	}

	public SimpleUpdateBuilder addWhereColumn(String columnName,
			Object value) {
		whereColumnMap.put(columnName, value);
		return this;
	}

	public SimpleUpdateBuilder setVersionColumn(String columnName,
			Object value) {
		versionColumnName = columnName;
		versionColumnValue = value;
		return this;
	}

	

	public SimpleUpdateBuilder(String tableName) {
		this.tableName = tableName;
	}

	public Query toQuery() {
		SimpleQueryBuilder builder = new SimpleQueryBuilder(256);
		builder.append("update ").append(tableName).append(" set ");
		boolean colflg = false;
		for (Iterator iterator = updateColumnMap.entrySet().iterator(); iterator.hasNext();) {
			Map.Entry entry = (Map.Entry) iterator.next();

			if(versionColumnName != null && versionColumnName.equalsIgnoreCase((String)entry.getKey()))
				continue;
			
			if (colflg)
				builder.append(',');
			colflg = true;
			builder.append((String)entry.getKey()).append("=?").bind(
					entry.getValue());
		}
		if (StringUtils.isNotEmpty(versionColumnName)) {
			if (colflg)
				builder.append(',');
			builder.append(versionColumnName).append("=?").bind(
					getNextVersion(versionColumnValue));
		}

		// ---------------where
		builder.append(" where ");
		boolean whereflg = false;
		for (Iterator iterator = whereColumnMap.entrySet().iterator(); iterator.hasNext();) {
			Map.Entry entry = (Map.Entry) iterator.next();
			
			if (whereflg)
				builder.append(" and ");
			whereflg = true;
			builder.append((String)entry.getKey()).append("=?").bind(
					entry.getValue());
		}
		// version
		if (StringUtils.isNotEmpty(versionColumnName) && versionColumnValue!=null) {
			if (whereflg)
				builder.append(" and ");
			builder.append(versionColumnName).append("=?").bind(
					versionColumnValue);
		}

		return builder.toQuery();
	}
	/**
	 * Version番号をCOUNT UPさせる。
	 * @param current
	 * @return
	 */
	static Object getNextVersion(Object current) {
		
		if (current instanceof Integer) {
			Integer i = (Integer) current;
			return new Integer(i.intValue() + 1);
		}
		if (current instanceof Long) {
			Long l = (Long) current;
			return new Long(l.longValue() + 1L);
		}
		if (current instanceof BigDecimal) {
			BigDecimal bd = (BigDecimal) current;
			return bd.add(BIGDECIMAL_ONE);
		}
		if (current instanceof Date) {
			return new Date();
		}
		return null;
	}
}

==> sx-dbutils-0.1.3-sources.jar: jp/sourceforge/sxdbutils/query/SimpleUpdateBuilder.java <==
package jp.sourceforge.sxdbutils.query;

import java.math.BigDecimal;
import java.util.Date;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
/**
 * UPDATE文の {@link Query}を作成するためのビルダーです。
 * @author chinpei
 *
 */
public class SimpleUpdateBuilder implements QueryBuilder{
	private final String tableName;
	private Map updateColumnMap = new LinkedHashMap();
	private Map whereColumnMap = new LinkedHashMap();

	private String versionColumnName;
	private Object versionColumnValue;
	private static final BigDecimal BIGDECIMAL_ONE=new BigDecimal("1");


	public SimpleUpdateBuilder addUpdateColumn(String columnName,
			Object value) {
		updateColumnMap.put(columnName, value);
		return this;
	}
	public SimpleUpdateBuilder addUpdateColumn(Map columnMap) {
		updateColumnMap.putAll(columnMap);
		return this;
	}

	public SimpleUpdateBuilder addWhereColumn(String columnName,
			Object value) {
		whereColumnMap.put(columnName, value);
		return this;
	}

	public SimpleUpdateBuilder setVersionColumn(String columnName,
			Object value) {
		versionColumnName = columnName;
		versionColumnValue = value;
		return this;
	}

	

	public SimpleUpdateBuilder(String tableName) {
		this.tableName = tableName;
	}

	public Query toQuery() {
		SimpleQueryBuilder builder = new SimpleQueryBuilder(256);
		builder.append("update ").append(tableName).append(" set ");
		boolean colflg = false;
		for (Iterator iterator = updateColumnMap.entrySet().iterator(); iterator.hasNext();) {
			Map.Entry entry = (Map.Entry) iterator.next();

			if(versionColumnName != null && versionColumnName.equalsIgnoreCase((String)entry.getKey()))
				continue;
			
			if (colflg)
				builder.append(',');
			colflg = true;
			builder.append((String)entry.getKey()).append("=?").bind(
					entry.getValue());
		}
		if (StringUtils.isNotEmpty(versionColumnName)) {
			if (colflg)
				builder.append(',');
			builder.append(versionColumnName).append("=?").bind(
					getNextVersion(versionColumnValue));
		}

		// ---------------where
		builder.append(" where ");
		boolean whereflg = false;
		for (Iterator iterator = whereColumnMap.entrySet().iterator(); iterator.hasNext();) {
			Map.Entry entry = (Map.Entry) iterator.next();
			
			if (whereflg)
				builder.append(" and ");
			whereflg = true;
			builder.append((String)entry.getKey()).append("=?").bind(
					entry.getValue());
		}
		// version
		if (StringUtils.isNotEmpty(versionColumnName) && versionColumnValue!=null) {
			if (whereflg)
				builder.append(" and ");
			builder.append(versionColumnName).append("=?").bind(
					versionColumnValue);
		}

		return builder.toQuery();
	}
	/**
	 * Version番号をCOUNT UPさせる。
	 * @param current
	 * @return
	 */
	static Object getNextVersion(Object current) {
		
		if (current instanceof Integer) {
			Integer i = (Integer) current;
			return new Integer(i.intValue() + 1);
		}
		if (current instanceof Long) {
			Long l = (Long) current;
			return new Long(l.longValue() + 1L);
		}
		if (current instanceof BigDecimal) {
			BigDecimal bd = (BigDecimal) current;
			return bd.add(BIGDECIMAL_ONE);
		}
		if (current instanceof Date) {
			return new Date();
		}
		return null;
	}
}
